==> flauto-6.4.2%2B9.tar.gz: README.md <==
## Flutter Sound

<img src="doc/flutter_sound/Logotype primary.png" width="70%" height="70%" />

<p align="left">
  <a href="https://pub.dartlang.org/packages/flauto"><img alt="pub version" src="https://img.shields.io/pub/v/flauto.svg?style=flat-square"></a>
</p>

-------------------------------------------------------------------------------------

# Flutter Sound user: your [documentation is there](https://canardoux.github.io/tau/book/flutter_sound/)
# The [CHANGELOG file is here](https://canardoux.github.io/tau/book/CHANGELOG.html)

-------------------------------------------------------------------------------------


This plugin provides simple recorder and player functionalities for
- Android
- iOS
- Flutter Web

[zozo](api/flutter_sound/black.html)

[toto](api/index.html)

[toto](player.html)

[I'm an inline-style link](https://www.google.com)

[I'm an inline-style link with title](https://www.google.com "Google's Homepage")

[I'm a reference-style link][Arbitrary case-insensitive reference text]

[I'm a relative reference to a repository file](../flutter_sound/api/index.html)

 <a href="api/index.html">Visit W3Schools.com!</a>

 [riri](api/flutter_sound/black.html)

 [riri](https://canardoux.github.io/tau/doc/flutter_sound/book/api/index.html)

 [papa](/api/index.html)


-----------------------------------------------------------------------------------------------------------------------------------

# Flutter Sound V6.x is OUT

Please refer to the [CHANGELOG.md file](../CHANGELOG.md) to get learn all the great new features. It has especially the following :

## Flutter Web support

Flutter Sound is supported by Flutter Web. You can play with [this live demo on the web](https://www.canardoux.space/tau/flutter_sound_example) (still cannot record with Safari or any web browser on iOS). You can [read this](doc/codec.md#flutter-sound-on-flutter-web).

## Record to Dart Stream

This feature has been requested from many months from many, many, many Flutter Sound users. This open doors to things like feeding a Speech-to-Text engine.

You can refer to the [Getting Started with Record-to-Stream](doc/codec.md#recording-pcm-16-to-a-dart-stream) notice.

## Playback from a live Dart Stream

This feature has also been requested from many months from many Flutter Sound users.

You can refer to the [Getting Started with Playback-from-Stream](doc/codec.md#playing-pcm-16-from-a-dart-stream) notice.

------------------------------------------------------------------------------------------------------------------------------------


![Demo](https://user-images.githubusercontent.com/27461460/77531555-77c9ec00-6ed6-11ea-9813-320f943b08cc.gif)

## Features

- Play and Record sounds or music with various codecs. (See [the supported codecs here](doc/codec.md#actually-the-following-codecs-are-supported-by-flutter_sound))
- Play local or remote files specified by their URL.
- Record to a Dart Stream
- Playback from a Dart Stream
- The App playback can be controled from the device lock screen or from an Apple watch

## Supported platforms

Flutter Sound is actually supported by :
- Android
- iOS
- Flutter Web

Maybe, one day, we will be supported by Linux, Macos, and even (why not) Windows. But this is not top of our priorities.

## Changelog

You can find the [changes here](../CHANGELOG.md)


## Documentation

The [documentation is here](https://canardoux.github.io/tau/doc/flutter_sound)


## License

Flutter Sound is copyrighted by Dooboolab (2018, 2019, 2020).
Flutter Sound is released under a license with a *copyleft* clause: the LGPL-V3 license. This means that if you modify some of Flutter Sound code you must publish your modifications under the LGPL license too.

## Contributions

Flutter Sound is a free and Open Source project. Several contributors have already contributed to Flutter Sound. Specially :
- @hyochan who is the Flutter Sound father
- @salvatore373 who wrote the Track Player
- @bsutton who wrote the UI Widgets
- @larpoux who add several codec supports

**We really need your contributions.**
Pull Requests are welcome and will be considered very carefully.



## Help Maintenance

My friend Hyo has been maintaining quite many repos these days and he is burning out slowly. If you could help him cheer up, buy him a cup of coffee will make his life really happy and get much energy out of it. As a side effect, we will know that Flutter Sound is important for you, that you appreciate our job and that you can show it with a little money.

<a href="https://www.buymeacoffee.com/dooboolab" target="_blank"><img src="https://www.buymeacoffee.com/assets/img/custom_images/purple_img.png" alt="Buy Me A Coffee" style="height: auto !important;width: auto !important;" ></a>
[![Paypal](https://www.paypalobjects.com/webstatic/mktg/Logo/pp-logo-100px.png)](https://paypal.me/dooboolab)

==> flauto-6.4.3%2B9.tar.gz: README.md <==
## Flutter Sound

<img src="Logotype primary.png" width="70%" height="70%" />

<p align="left">
  <a href="https://canardoux.github.io/tau/book/flauto"><img alt="pub version" src="https://img.shields.io/pub/v/flauto.svg?style=flat-square"></a>
</p>

-------------------------------------------------------------------------------------

# Flutter Sound user: your [documentation is there](https://canardoux.github.io/tau/book/flutter_sound/)
# The [CHANGELOG file is here](https://canardoux.github.io/tau/book/CHANGELOG.html)

-------------------------------------------------------------------------------------


This plugin provides simple recorder and player functionalities for
- Android
- iOS
- Flutter Web

[coco](api/flutter_sound/black.html)

[popo](api/index.html)

[nono](player.html)

[I'm an inline-style link](https://www.google.com)

[I'm an inline-style link with title](https://www.google.com "Google's Homepage")

[I'm a reference-style link][Arbitrary case-insensitive reference text]

[I'm a relative reference to a repository file](../flutter_sound/api/index.html)

 <a href="api/index.html">Visit W3Schools.com!</a>

 [tutu](api/flutter_sound/black.html)

 [lulu](https://canardoux.github.io/tau/doc/flutter_sound/book/api/index.html)

 [maman](/api/index.html)


-----------------------------------------------------------------------------------------------------------------------------------

# Flutter Sound V6.x is OUT

Please refer to the [CHANGELOG.md file](https://canardoux.github.io/tau/book/CHANGELOG.html) to get learn all the great new features. It has especially the following :

## Flutter Web support

Flutter Sound is supported by Flutter Web. You can play with [this live demo on the web](https://canardoux.github.io/tau/doc/flutter_sound/web) (still cannot record with Safari or any web browser on iOS). You can [read this](https://dooboolab.github.io/flutter_sound/book/flutter_sound/codec.html#flutter-sound-on-flutter-web).

## Record to Dart Stream

This feature has been requested from many months from many, many, many Flutter Sound users. This open doors to things like feeding a Speech-to-Text engine.

You can refer to the [Getting Started with Record-to-Stream](https://canardoux.github.io/tau/book/flutter_sound/codec.html#recording-pcm-16-to-a-dart-stream) notice.

## Playback from a live Dart Stream

This feature has also been requested from many months from many Flutter Sound users.

You can refer to the [Getting Started with Playback-from-Stream](https://canardoux.github.io/tau/book/flutter_sound/codec.html#playing-pcm-16-from-a-dart-stream) notice.

------------------------------------------------------------------------------------------------------------------------------------


![Demo](https://user-images.githubusercontent.com/27461460/77531555-77c9ec00-6ed6-11ea-9813-320f943b08cc.gif)

## Features

- Play and Record sounds or music with various codecs. (See [the supported codecs here](https://canardoux.github.io/tau/book/flutter_sound/codec.html#flutter-sound-codecs))
- Play local or remote files specified by their URL.
- Record to a Dart Stream
- Playback from a Dart Stream
- The App playback can be controled from the device lock screen or from an Apple watch

## Supported platforms

Flutter Sound is actually supported by :
- Android
- iOS
- Flutter Web

Maybe, one day, we will be supported by Linux, Macos, and even (why not) Windows. But this is not top of our priorities.

## Changelog

You can find the [changes here](https://canardoux.github.io/tau/book/CHANGELOG.html)


## Documentation

The [documentation is here](https://canardoux.github.io/tau/book/flutter_sound/)


## License

Flutter Sound is copyrighted by Dooboolab (2018, 2019, 2020).
Flutter Sound is released under a license with a *copyleft* clause: the LGPL-V3 license. This means that if you modify some of Flutter Sound code you must publish your modifications under the LGPL license too.


## Help Maintenance

My friend Hyo has been maintaining quite many repos these days and he is burning out slowly. If you could help him cheer up, buy him a cup of coffee will make his life really happy and get much energy out of it. As a side effect, we will know that Flutter Sound is important for you, that you appreciate our job and that you can show it with a little money.

<a href="https://www.buymeacoffee.com/dooboolab" target="_blank"><img src="https://www.buymeacoffee.com/assets/img/custom_images/purple_img.png" alt="Buy Me A Coffee" style="height: auto !important;width: auto !important;" ></a>
[![Paypal](https://www.paypalobjects.com/webstatic/mktg/Logo/pp-logo-100px.png)](https://paypal.me/dooboolab)
